##  Use the AI Agent Hub Dashboard
If you’re using the [AI agent hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD "Discover and manage AI agents across the organization."), you can track key KPIs for AI agents and get quick access to reports and other items from the AI agent hub dashboard.
  * Monitor KPIs: Track KPIs for AI agents to understand the status of your AI agent inventory. These KPIs are also displayed on the architecture executive dashboard. To learn how to use the dashboard and drill down to KPI data, see [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "The architecture executive dashboard provides essential KPIs related to the organization’s IT landscape, enabling informed, data-driven decision-making through valuable insights.").
  * View discovered AI agents: Check the status of discovered AI agents and navigate to the AI agent discovery inbox directly from the dashboard.
  * Navigate to saved searches and AI agent fact sheets: Quickly access saved searches for AI agents and navigate to recently updated AI agent fact sheets.
  * Preview reports for AI agents: View dedicated reports for AI agents and navigate to them from the dashboard for a more detailed analysis.


To learn more, see [AI Agent Hub Dashboard](https://help.sap.com/docs/leanix/ea/ai-agent-hub-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "Use the AI agent hub dashboard to get an overview of AI agent data in your workspace.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioe29c7146bc0344769a92d57f5f94a74c_LowRes.png)
AI Agent Hub Dashboard
